.. Multi-Input Medical Image ML Toolkit documentation master file, created by
   sphinx-quickstart on Tue Jun  4 14:18:38 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to Multi-Input Medical Image ML Toolkit's documentation!
================================================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

Indices and tables
==================

* :ref:`genindex`
* :ref:`search`

Contents
--------

.. toctree::
   :maxdepth: 3
   
   usage
 
   modules
